summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorRoozbeh Pournader <roozbeh@google.com>2014-07-22 12:56:24 -0700
committerRoozbeh Pournader <roozbeh@google.com>2014-07-22 12:56:24 -0700
commite4b52200a1bc23508712df300df45fa34ef271c9 (patch)
tree693987a5242381f2372859232e8c81ef1cea579b /scripts
parent97bb2636965b92cce7deb79eb96bb79af97bd73c (diff)
Minor fixes in wording and documentation for Glass touchup script.
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/touchup_for_glass.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/scripts/touchup_for_glass.py b/scripts/touchup_for_glass.py
index 1374e32..2bc5128 100755
--- a/scripts/touchup_for_glass.py
+++ b/scripts/touchup_for_glass.py
@@ -10,7 +10,7 @@ from nototools import font_data
def apply_glass_hacks(font):
- """Apply glass-specific hacks."""
+ """Apply glass-specific hacks to a fonttools font instance."""
# Really ugly hack, expecting the proportional digit one to be at
# glyph01965.
font_data.add_to_cmap(font, {0xEE00: 'glyph01965'})
@@ -36,16 +36,16 @@ def apply_glass_hacks(font):
assert False
-def correct_font(source_font_name, target_font_name):
- """Corrects metrics and other meta information."""
+def hack_font(source_font_name, target_font_name):
+ """Hacks the source font and saves it as the target."""
font = ttLib.TTFont(source_font_name)
apply_glass_hacks(font)
font.save(target_font_name)
def main(argv):
- """Correct the font specified in the command line."""
- correct_font(argv[1], argv[2])
+ """Hack the font specified in the command line."""
+ hack_font(argv[1], argv[2])
if __name__ == "__main__":